diff --git a/ACL/src/Transport/HTTP2Stream.cpp b/ACL/src/Transport/HTTP2Stream.cpp
index e1cd408..c52bdcc 100644
--- a/ACL/src/Transport/HTTP2Stream.cpp
+++ b/ACL/src/Transport/HTTP2Stream.cpp
@@ -193,6 +193,29 @@ bool HTTP2Stream::setCommonOptions(const std::string& url, const std::string& au
         return false;
     }
 
+    //TODO：此处暂时添加一个固定的device id，需要改为method去获取device id
+    std::ostringstream dsnHeader;
+    dsnHeader << "Dueros-Device-Id: avstest123";
+    if (!m_transfer.addHTTPHeader(dsnHeader.str())) {
+        ACSDK_ERROR(LX("setCommonOptionsFailed")
+                            .d("reason", "addHTTPHeaderFailed")
+                            .sensitive("dsnHeader", dsnHeader.str()));
+        return false;
+    }
+
+    /**
+     * amazon代码发送请求时，会添加content length字段，而我们发送音频数据时，是无法获知
+     * length的，baidu的服务器也没有对这个情况做兼容
+     */
+    std::ostringstream teHeader;
+    teHeader << "Transfer-Encoding: chunked";
+    if (!m_transfer.addHTTPHeader(teHeader.str())) {
+        ACSDK_ERROR(LX("setCommonOptionsFailed")
+                            .d("reason", "addHTTPHeaderFailed")
+                            .sensitive("teHeader", teHeader.str()));
+        return false;
+    }
+
     if (!m_transfer.setWriteCallback(&HTTP2Stream::writeCallback, this)) {
         ACSDK_ERROR(LX("setCommonOptionsFailed").d("reason", "setWriteCallbackFailed"));
         return false;
diff --git a/ACL/src/Transport/HTTP2Transport.cpp b/ACL/src/Transport/HTTP2Transport.cpp
index 6b497c1..64d732a 100644
--- a/ACL/src/Transport/HTTP2Transport.cpp
+++ b/ACL/src/Transport/HTTP2Transport.cpp
@@ -50,13 +50,13 @@ static const std::string TAG("HTTP2Transport");
  */
 const static int MAX_STREAMS = 10;
 /// Default @c AVS endpoint to connect to.
-const static std::string DEFAULT_AVS_ENDPOINT = "https://avs-alexa-na.amazon.com";
+const static std::string DEFAULT_AVS_ENDPOINT = "https://dueros-h2.baidu.com";
 /// Downchannel URL
-const static std::string AVS_DOWNCHANNEL_URL_PATH_EXTENSION = "/v20160207/directives";
+const static std::string AVS_DOWNCHANNEL_URL_PATH_EXTENSION = "/dcs/avs-compatible-v20160207/directives";
 /// URL to send events to
-const static std::string AVS_EVENT_URL_PATH_EXTENSION = "/v20160207/events";
+const static std::string AVS_EVENT_URL_PATH_EXTENSION = "/dcs/avs-compatible-v20160207/events";
 /// URL to send pings to
-const static std::string AVS_PING_URL_PATH_EXTENSION = "/ping";
+const static std::string AVS_PING_URL_PATH_EXTENSION = "/dcs/avs-compatible-v20160207/ping";
 /// Timeout for curl_multi_wait
 const static std::chrono::milliseconds WAIT_FOR_ACTIVITY_TIMEOUT(100);
 /// Timeout for curl_multi_wait while all HTTP/2 event streams are paused.
@@ -664,7 +664,10 @@ bool HTTP2Transport::sendPing() {
 
 void HTTP2Transport::handlePingResponse() {
     ACSDK_DEBUG(LX("handlePingResponse"));
-    if (HTTP2Stream::HTTPResponseCodes::SUCCESS_NO_CONTENT != m_pingStream->getResponseCode()) {
+    // 此处amazon的服务器需要返回204，而baidu的服务器会返回200，为兼容这个情况，此处加上200的处理
+    // 另外当返回值不正确时，此处会stop sample app，此处的逻辑可能需要更改
+    if (HTTP2Stream::HTTPResponseCodes::SUCCESS_NO_CONTENT != m_pingStream->getResponseCode()
+        && HTTP2Stream::HTTPResponseCodes::SUCCESS_OK != m_pingStream->getResponseCode()) {
         ACSDK_ERROR(LX("pingFailed").d("responseCode", m_pingStream->getResponseCode()));
         setIsStopping(ConnectionStatusObserverInterface::ChangedReason::SERVER_SIDE_DISCONNECT);
     }
diff --git a/AVSCommon/Utils/src/LibcurlUtils/CurlEasyHandleWrapper.cpp b/AVSCommon/Utils/src/LibcurlUtils/CurlEasyHandleWrapper.cpp
index 8638a3c..6ade47c 100644
--- a/AVSCommon/Utils/src/LibcurlUtils/CurlEasyHandleWrapper.cpp
+++ b/AVSCommon/Utils/src/LibcurlUtils/CurlEasyHandleWrapper.cpp
@@ -39,7 +39,7 @@ static const std::string TAG("CurlEasyHandleWrapper");
 #define LX(event) alexaClientSDK::avsCommon::utils::logger::LogEntry(TAG, event)
 
 /// MIME Content-Type for JSON data
-static std::string JSON_MIME_TYPE = "text/json";
+static std::string JSON_MIME_TYPE = "application/json";
 /// MIME Content-Type for octet stream data
 static std::string OCTET_MIME_TYPE = "application/octet-stream";
 /// Response code for HTTP 204 (Success No Content response)
diff --git a/AuthDelegate/src/AuthDelegate.cpp b/AuthDelegate/src/AuthDelegate.cpp
index dbe1617..96537a9 100644
--- a/AuthDelegate/src/AuthDelegate.cpp
+++ b/AuthDelegate/src/AuthDelegate.cpp
@@ -67,7 +67,7 @@ const char* CONFIG_KEY_REQUEST_TIMEOUT = "requestTimeout";
 const char* CONFIG_KEY_AUTH_TOKEN_REFRESH_HEAD_START = "authTokenRefreshHeadStart";
 
 /// Default value for lwaURL.
-static const std::string DEFAULT_LWA_URL = "https://api.amazon.com/auth/o2/token";
+static const std::string DEFAULT_LWA_URL = "https://openapi.baidu.com/oauth/2.0/token";
 
 /// Default value for requestTimeout.
 static const std::chrono::minutes DEFAULT_REQUEST_TIMEOUT = std::chrono::minutes(5);
diff --git a/CapabilityAgents/System/test/EndpointHandlerTest.cpp b/CapabilityAgents/System/test/EndpointHandlerTest.cpp
index 85e79c3..bcdfdce 100644
--- a/CapabilityAgents/System/test/EndpointHandlerTest.cpp
+++ b/CapabilityAgents/System/test/EndpointHandlerTest.cpp
@@ -50,7 +50,7 @@ static const std::string ENDPOINTING_WRONG_NAME = "WrongEndpointer";
 static const std::string ENDPOINT_PAYLOAD_KEY = "endpoint";
 
 /// This is the string for the endpoint payload.
-static const std::string ENDPOINT_PAYLOAD_VALUE = "https://avs-alexa-na.amazon.com";
+static const std::string ENDPOINT_PAYLOAD_VALUE = "https://dueros-h2.baidu.com";
 
 /// This is the full payload expected to come from AVS.
 static const std::string ENDPOINT_PAYLOAD = "{\"" + ENDPOINT_PAYLOAD_KEY + "\": \"" + ENDPOINT_PAYLOAD_VALUE + "\"}";
